# Tag Report Utility Excel export functions.

# Copyright 2024 Automation Professionals, LLC <sales@automation-pros.com>
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#   1. Redistributions of source code must retain the above copyright notice,
#      this list of conditions and the following disclaimer.
#   2. Redistributions in binary form must reproduce the above copyright notice,
#      this list of conditions and the following disclaimer in the documentation
#      and/or other materials provided with the distribution.
#   3. The name of the author may not be used to endorse or promote products
#      derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
# OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
# OF SUCH DAMAGE.

from java.io import ByteArrayOutputStream
from java.util import Date
from org.apache.poi.ss.usermodel import Cell, Row, Sheet, Workbook
from org.apache.poi.xssf.usermodel import XSSFWorkbook, XSSFFont, XSSFDataFormat

logger = system.util.getLogger(system.util.getProjectName()+'.'+system.reflect.getModulePath())

# Workbook Cell Style Utility 
def createFontStyle(wb, font, points, bold):
	style = wb.createCellStyle()
	cellFont = wb.createFont()
	cellFont.bold = bold
	cellFont.fontHeightInPoints = points
	cellFont.fontName = font
	style.setFont(cellFont)
	return style
#

# Start an empty workbook
def createWorkbook():
	wb = XSSFWorkbook()
	fmt = wb.createDataFormat()
	hStyle = exchange.tagReportUtility.excel.createFontStyle(wb, 'Calibri', 10, True)
	rStyle = createFontStyle(wb, 'Calibri', 10, False)
	dStyle = createFontStyle(wb, 'Calibri', 10, False)
	dStyle.dataFormat = fmt.getFormat('yyyy-mm-dd hh:mm:ss.000')
	jStyle = createFontStyle(wb, 'Courier New', 10, False)
	return wb, hStyle, rStyle, dStyle, jStyle
#

# Send a finished Workbook to a browser.  Must be called in a Perspective
# Page or View context.
def downloadWorkbook(wb, outputName):
	# Produce and deliver Excel Bytes.
	baos = ByteArrayOutputStream()
	wb.write(baos)
	system.perspective.download(outputName, baos.toByteArray(), 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet')
#
#
# kate: tab-width 4; indent-width 4; tab-indents on; dynamic-word-wrap off; indent-mode python; line-numbers on;
